@@ -266,8 +266,8 @@ doEvent.", name, " = function(sim, eventTime, eventType, debug = FALSE) {
 
     # ! ----- STOP EDITING ----- ! #
   } else {
-    warning(paste(\"Undefined event type: \'\", events(sim)[1, \"eventType\", with = FALSE],
-                  \"\' in module \'\", events(sim)[1, \"moduleName\", with = FALSE], \"\'\", sep = \"\"))
+    warning(paste(\"Undefined event type: \'\", current(sim)[1, \"eventType\", with = FALSE],
+                  \"\' in module \'\", current(sim)[1, \"moduleName\", with = FALSE], \"\'\", sep = \"\"))
   }
   return(invisible(sim))
 }
@@ -676,11 +676,11 @@ setMethod("openModules",
             basedir <- checkPath(path, create = FALSE)
             origDir <- getwd()
             setwd(basedir)
-            if (any(names == "all")) {
+            if (any(name == "all")) {
               Rfiles <- dir(pattern = "[\\.][rR]$", recursive = TRUE)
             } else {
               Rfiles <- dir(pattern = "[\\.][rR]$", recursive = TRUE)
-              Rfiles <- Rfiles[pmatch(name,Rfiles)]
+              Rfiles <- Rfiles[pmatch(name, Rfiles)]
             }
             Rfiles <- Rfiles[grep(pattern = "[/\\\\]",Rfiles)]
             Rfiles <- Rfiles[sapply(strsplit(Rfiles,"[/\\\\\\.]"),
