@@ -109,9 +109,13 @@ setReplaceMethod(
   "setColors",
   signature("RasterLayer", "numeric", "character"),
   function(object, ..., n, value) {
+    if(is.na(n)) {
+      object <- setColors(object=object, value=value)
+      return(object)
+    }
     if (raster::is.factor(object)) {
       if (n != NROW(object@data@attributes[[1]])) {
-        warning("Number of colors not equal number of values: interpolating")
+        message("Number of colors not equal number of values: interpolating")
         pal <- colorRampPalette(value, alpha = TRUE, ...)
         n <- NROW(object@data@attributes[[1]])
         object@legend@colortable <- pal(n)
@@ -122,7 +126,7 @@ setReplaceMethod(
       pal <- colorRampPalette(value, alpha = TRUE, ...)
       object@legend@colortable <- pal(n)
     }
-    if(!is.character(object@legend@colortable)) stop("setColors needs color character values")
+    if (!is.character(object@legend@colortable)) stop("setColors needs color character values")
     return(object)
 })
 
@@ -132,13 +136,13 @@ setReplaceMethod(
   "setColors",
   signature("RasterLayer", "missing", "character"),
   function(object, ..., value) {
-    if(!raster::is.factor(object)) {
+    if (!raster::is.factor(object)) {
       n <- round((maxValue(object) - minValue(object))) + 1
     } else {
       n <- length(value)
     }
     setColors(object, n=n) <- value
-    if(!is.character(object@legend@colortable)) stop("setColors needs color character values")
+    if (!is.character(object@legend@colortable)) stop("setColors needs color character values")
     return(object)
 })
 
@@ -148,8 +152,26 @@ setReplaceMethod(
    signature("RasterStack", "numeric", "list"),
    function(object, ..., n, value) {
      i <- which(names(object) %in% names(value))
-     for(x in names(object)[i]) {
-       setColors(object[[x]], ..., n = n) <- value[[x]]
+     if (length(i) == 0) stop("Layer names do not match stack layer names")
+     whValNamed <- names(value)[i] %in% names(n)
+     whNNamed <- names(n) %in% names(value)[i]
+     nFull <- n
+     if (length(n) != length(i)) { # not enough n values}
+       if (sum(nchar(names(n)) == 0) > 0) { # are there unnamed ones
+         nFull <- rep(n[!whNNamed], length.out = length(i))
+         nFull[whValNamed] <- n[whNNamed]
+         names(nFull)[whValNamed] <- names(n)[whNNamed]
+       } else if (is.null(names(n))) {
+         nFull <- rep(n, length.out = length(i))
+       }
+     }
+
+     for (x in i) {
+       if ((x %in% i[whValNamed])) {
+         setColors(object[[names(value)[x]]], ..., n = nFull[[names(value)[x]]]) <- value[[names(value)[x]]]
+       } else {
+         setColors(object[[names(value)[x]]], ..., n = nFull[x]) <- value[[names(value)[x]]]
+       }
      }
      return(object)
 })
@@ -160,7 +182,7 @@ setReplaceMethod(
    signature("Raster", "missing", "list"),
    function(object, ..., value) {
      i <- which(names(object) %in% names(value))
-     for(x in names(object)[i]) {
+     for (x in names(object)[i]) {
        setColors(object[[x]], ...) <- value[[x]]
      }
      return(object)
@@ -273,19 +295,19 @@ setMethod(
     #  so, use the metadata version of minValue, but use the max(z) to
     #  accomodate cases where there are too many legend values for the
     # number of raster values.
-    if(any(is.na(legendRange))) {
+    if (any(is.na(legendRange))) {
       if (!exists("minz")) {
         minz <- suppressWarnings(min(z, na.rm = TRUE))
       }
       if (is.na(minz)) {
         minz <- suppressWarnings(min(z, na.rm = TRUE))
       }
-      if(is.infinite(minz)) {
+      if (is.infinite(minz)) {
         minz <- 0
       }
       #
       maxz <- suppressWarnings(max(z, na.rm = TRUE))
-      if(is.infinite(maxz)) {
+      if (is.infinite(maxz)) {
         maxz <- 0
       }
     } else {
@@ -306,8 +328,7 @@ setMethod(
       #realRange <- any(legendRange %% 1 != 0) # Test for real values or not
       nValues <- ifelse(real, maxNumCols + 1, length(seq(legendRange[1], legendRange[length(legendRange)])))
     }
-      #nValues <- maxz - minz + 1
-#    }
+
     colTable <- NULL
     if (is.null(cols)) {
       # i.e., contained within raster or nothing
@@ -318,16 +339,16 @@ setMethod(
         cols <- if ((nValues > lenColTable) & !raster::is.factor(grobToPlot)) {
           # not enough colors, use colorRamp
           colorRampPalette(colTable)(nValues)
-        } else if ((nValues <= (lenColTable)) | raster::is.factor(grobToPlot)) {
+        } else if ( (nValues <= lenColTable) | raster::is.factor(grobToPlot) ) {
           # one more color than needed:
           #   assume bottom is NA
-          if(raster::is.factor(grobToPlot)) {
+          if (raster::is.factor(grobToPlot)) {
             factorValues <- grobToPlot@data@attributes[[1]][,1] %>%
-              unique %>% na.omit %>% sort
-            if(length(factorValues)==length(colTable)) {
+              unique() %>% na.omit() %>% sort()
+            if (length(factorValues) == length(colTable)) {
               colTable[seq.int(length(factorValues))]
             } else {
-              colTable[c(1,1+factorValues)] # CHANGE HERE
+              colTable[c(1, 1 + factorValues)] # CHANGE HERE
             }
           } else {
             colTable
@@ -351,8 +372,8 @@ setMethod(
         cols <- rev(terrain.colors(nValues))
       }
     } else {
-      if(is.character(cols) & (length(cols)==1)) {
-        if(cols %in% rownames(brewer.pal.info)) {
+      if (is.character(cols) & (length(cols) == 1)) {
+        if (cols %in% rownames(brewer.pal.info)) {
           suppressWarnings(cols <- brewer.pal(nValues, cols))
         } else {
           warning("Color not recognized. Try RColorBrewer or default R colors")
@@ -388,15 +409,15 @@ setMethod(
     maxzOrig <- maxz
     whichZero <- numeric()
     whichZeroLegend <- numeric()
-    if(!is.null(zero.color)){
+    if (!is.null(zero.color)){
       whichZero <- which(z==0)
       whichZeroLegend <- which(seq(minz, maxz, length.out=nValues)==0)
     }
 
     # Here, rescale so it is between 0 and maxNumCols or nValues
-    if (real ){#& (maxz <= maxNumCols) ) {
+    if (real) {#& (maxz <= maxNumCols) ) {
       z <- maxNumCols / (maxz - minz) * (z - minz)
-      if(length(whichZero)) {
+      if (length(whichZero)) {
         zeroValue <- maxNumCols / (maxz - minz) * (0 - minz)
       }
       # rescale so the minimum is 1, not <1:
@@ -405,16 +426,16 @@ setMethod(
     } else {
       # rescale so that the minimum is 1, not <1:
       z <- (nValues - 1) /  (maxz - minz) * (z - minz) + 1
-      if(length(whichZero)) {
+      if (length(whichZero)) {
         zeroValue <- (nValues - 1) / (maxz - minz) * (0 - minz) + 1
       }
     }
-    minz <- suppressWarnings(min(z, na.rm=TRUE))
-    maxz <- suppressWarnings(max(z, na.rm=TRUE))
-    if(is.infinite(minz)) {
+    minz <- suppressWarnings(min(z, na.rm = TRUE))
+    maxz <- suppressWarnings(max(z, na.rm = TRUE))
+    if (is.infinite(minz)) {
       maxz <- 0
     }
-    if(is.infinite(minz)) {
+    if (is.infinite(minz)) {
       minz <- 0
     }
 
@@ -426,7 +447,7 @@ setMethod(
         #minzOrig <- minz
         #maxzOrig <- maxz
         if (is.null(colTable)) {
-#          cols <- colorRampPalette(cols)(maxz - minz + 1)
+          #cols <- colorRampPalette(cols)(maxz - minz + 1)
         } else {
           if (length(getColors(grobToPlot)[[1]]) > 0) {
             cols <- colorRampPalette(colTable)(maxzOrig - minzOrig + 1)
@@ -442,21 +463,21 @@ setMethod(
     # if it is the minimum value, can be overridden.
 
     # if range of values is not within the legend range, then give them NA
-    if(minz<0) z[z<0] <- 0
-    if(real) {
-      if(maxz>maxNumCols) z[z>maxNumCols] <- 0
+    if (minz < 0) z[z < 0] <- 0
+    if (real) {
+      if (maxz > maxNumCols) z[z > maxNumCols] <- 0
     } else {
-      if(maxz>nValues) z[z>nValues] <- 0
+      if (maxz > nValues) z[z > nValues] <- 0
     }
 
     z <- z + 1 # for the NAs
     z[is.na(z)] <- 1 # max(1, minz)
 
-    if(raster::is.factor(grobToPlot) & !is.null(colTable)){
+    if (raster::is.factor(grobToPlot) & !is.null(colTable)) {
       cols <- rep(na.color,max(factorValues))
       cols[factorValues] <- colTable
     }
-    if(length(whichZeroLegend)) {
+    if (length(whichZeroLegend)) {
       cols[whichZeroLegend] <- zero.color
     }
     cols <- c(na.color, cols) # make first index of colors be transparent
