@@ -222,7 +222,7 @@ setGeneric("envir<-",
 setReplaceMethod("envir",
                  signature = "simList",
                  function(object, value) {
-                   if(!is.environment(value)) stop("Must be an environment")
+                   if (!is.environment(value)) stop("Must be an environment")
                    object@.envir <- value
                    return(object)
 })
@@ -813,88 +813,70 @@ setReplaceMethod("progressType",
                    return(object)
 })
 
-################################################################################
-#' Create empty fileTable for inputs and outputs
-#'
-#' Internal functions.
-#' Returns an empty fileTable to be used with inputs and outputs.
-#'
-#' @param x  Not used (should be missing)
-#'
-#' @return An empty data.frame with structure needed for input/output fileTable.
-#'
-#' @docType methods
-#' @rdname fileTable
-#'
-setGeneric(".fileTableIn", function(x) {
-  standardGeneric(".fileTableIn")
-})
-
-#' @rdname fileTable
-setMethod(
-  ".fileTableIn",
-  signature = "missing",
-  definition = function() {
-    ft <- data.frame(
-      file = character(0), fun = character(0), package = character(0),
-      objectName = character(0), loadTime = numeric(0), loaded = logical(0),
-      stringsAsFactors = FALSE
-    )
-    return(ft)
-})
-
-#' @rdname fileTable
-.fileTableInCols <- colnames(.fileTableIn())
-
-#' @rdname fileTable
-setGeneric(".fileTableOut", function(x) {
-  standardGeneric(".fileTableOut")
-})
-
-#' @rdname fileTable
-setMethod(
-  ".fileTableOut",
-  signature = "missing",
-  definition = function() {
-    ft <- data.frame(
-      file = character(0), fun = character(0), package = character(0),
-      objectName = character(0), saveTime = numeric(0), saved = logical(0),
-      stringsAsFactors = FALSE
-    )
-    return(ft)
-})
-
-#' @rdname fileTable
-.fileTableOutCols <- colnames(.fileTableOut())
 
 ################################################################################
 #' Inputs and outputs
 #'
-#' Accessor functions for the \code{inputs} and \code{outputs} slots in a
-#' \code{simList} object.
-#'
 #' These functions are one of two mechanisms to add the information about which
 #' input files to load in a \code{spades} call and the information about which
 #' output files to save.
 #' The other way is to pass them as arguments to a \code{simInit} call.
 #'
-#' Currently, only get and set methods are defined. Subset methods are not.
+#' Accessor functions for the \code{inputs} and \code{outputs} slots in a
+#' \code{simList} object.
+#'
+#' @section inputs:
+#'
+#' \code{inputs} accepts a data.frame, with up to 7 columns.
+#' Columns are:
+#'
+#' \tabular{ll}{
+#' \code{file} \tab required, a character string indicating the file path. There is no
+#' default.\cr
+#'
+#' \code{objectName} \tab optional, character string indicating the name of the object
+#' that the loaded file will be assigned to in the \code{simList}. This object
+#' can therefore be accessed with \code{sim$xxx} in any module, where
+#' \code{objectName = "xxx"}. Defaults to the filename without file extension or
+#' directory information.\cr
+#'
+#' \code{fun} \tab optional, a character string indicating the function to use to
+#' load that file. Defaults to the known extentions in \code{SpaDES} (found by
+#' examining \code{.fileExtensions()}). The \code{package} and \code{fun} can be
+#' jointly specified here as \code{"packageName::functionName"}, e.g.,
+#' \code{"raster::raster"}.\cr
+#'
+#' \code{package} \tab optional character string indicating the package in
+#' which to find the \code{fun});\cr
+#'
+#' \code{loadTime} \tab optional numeric, indicating when in simulation time the file
+#' should be loaded. The default is the highest priority at \code{start(sim)},
+#' i.e., at the very start. \cr
+#'
+#' \code{interval} \tab optional numeric, indicating at what interval should this same
+#' exact file  be reloaded from disk, e.g,. 10 would mean every 10 time units. The
+#' default is NA or no interval, i.e, load the file only once as described in
+#' \code{loadTime} \cr
+#'
+#' \code{arguments} \tab is a list of lists of named arguments, one list for each
+#' \code{fun}. For example, if \code{fun="raster"}, \code{arguments = list(native = TRUE)}
+#' will pass the argument "native = TRUE" to raster.  If there is only one list,
+#' then it is assumed to apply to all files and will be recycled as per normal R
+#' rules of recycling for each \code{fun}.\cr
+#'
+#' }
+#'
+#' Currently, only \code{file} is required. All others will be filled with defaults
+#' if not specified.
 #'
-#' @details \code{inputs} accepts a data.frame, with 6 columns.
-#' Currently, only one is required.
 #' See the modules vignette for more details (\code{browseVignettes("SpaDES")}).
-#' Columns are \code{objectName} (required, character),
-#' \code{file} (character),
-#' \code{fun} (character),
-#' \code{package} (character),
-#' \code{interval} (numeric),
-#' and \code{loadTime} (numeric).
 #'
 #' @param object A \code{simList} simulation object.
 #'
 #' @param value The object to be stored at the slot.
 #'
-#' @return Returns or sets the value of the slot from the \code{simList} object.
+#' @return Returns or sets the value(s) of the \code{input} or \code{output} slots
+#' in the \code{simList} object.
 #'
 #' @seealso \code{\link{simList-class}},
 #'          \code{\link{simList-accessors-modules}},
@@ -907,7 +889,6 @@ setMethod(
 #'
 #' @include simList-class.R
 #' @importFrom data.table is.data.table
-#' @importFrom dplyr bind_rows
 #' @importFrom stats na.omit
 #' @export
 #' @docType methods
@@ -922,22 +903,47 @@ setMethod(
 #' test <- 1:10
 #' tmpFile <- file.path(tempdir(), "test.rds")
 #' saveRDS(test, file=tmpFile)
-#' inputs(sim) <- data.frame(file = tmpFile)
+#' inputs(sim) <- data.frame(file = tmpFile) # using only required column, "file"
 #' inputs(sim) # see that it is not yet loaded, but when it is scheduled to be loaded
-#' sim <- spades(sim)
-#' inputs(sim) # confirm it was loaded
+#' simOut <- spades(sim)
+#' inputs(simOut) # confirm it was loaded
+#' simOut$test
 #'
 #' # can put data.frame for inputs directly inside simInit call
+#' allTifs <- dir(system.file("maps", package = "SpaDES"),
+#'                full.names = TRUE, pattern = "tif")
+#'
+#' # next: objectNames are taken from the filenames (without the extension)
+#' # This will load all 5 tifs in the SpaDES sample directory, using
+#' #   the raster fuction in the raster package, all at time = 0
 #' sim <- simInit(
 #'    inputs = data.frame(
-#'      files = dir(file.path(tmpFile), full.names = TRUE, pattern = "tif")[1:2],
+#'      files = allTifs,
 #'      functions = "raster",
 #'      package = "raster",
-#'      loadTime = 3,
+#'      loadTime = 0,
 #'      stringsAsFactors = FALSE)
 #'    )
-
-#' sim$test
+#'
+#' ##############################
+#' #A fully described inputs object, including arguments:
+#' files = dir(system.file("maps", package = "SpaDES"),
+#'             full.names = TRUE, pattern = "tif")
+#' # arguments must be a list of lists. This may require I() to keep it as a list
+#' #   once it gets coerced into the data.frame.
+#' arguments = I(rep(list(native = TRUE), length(files)))
+#' filelist = data.frame(
+#'    objectName = paste0("Maps",1:5),
+#'    files = files,
+#'    functions = "raster::raster",
+#'    arguments = arguments,
+#'    loadTime = 0,
+#'    intervals = c(rep(NA, length(files)-1), 10)
+#' )
+#' inputs(sim) <- filelist
+#' spades(sim)
+#'
+#'
 #' # Clean up after
 #' file.remove(tmpFile)
 setGeneric("inputs", function(object) {
@@ -952,11 +958,11 @@ setMethod("inputs",
 
             simUnit <- timeunit(object)
             loadTimeUnit <- attr(object@inputs$loadTime, "unit")
-            if(is.null(loadTimeUnit)) loadTimeUnit <- simUnit
-            out <- if(is.na(pmatch(loadTimeUnit, simUnit)) & (length(object@inputs$loadTime)>0)) {
+            if (is.null(loadTimeUnit)) loadTimeUnit <- simUnit
+            out <- if (is.na(pmatch(loadTimeUnit, simUnit)) & (length(object@inputs$loadTime)>0)) {
               #note the above line captures empty loadTime,
               # whereas is.na does not
-              if(any(!is.na(object@inputs$loadTime))) {
+              if (any(!is.na(object@inputs$loadTime))) {
                 if (!is.null(object@inputs$loadTime)) {
                   obj <- data.table::copy(object@inputs) # don't change original object
                   obj[,loadTime:=convertTimeunit(loadTime, unit, envir(object))]
@@ -988,32 +994,40 @@ setReplaceMethod(
   signature = ".simList",
   function(object, value) {
    if (length(value)>0) {
+     whFactors <- sapply(value, function(x) is.factor(x))
+     if (any(whFactors)) {
+       value[,whFactors] <- sapply(value[,whFactors], as.character)
+     }
+
      if (!is.data.frame(value)) {
        if (!is.list(value)) {
          stop("inputs must be a list, data.frame")
        }
-       # pull out any "arguments" that will be passed to input functions
-#       if (any(stri_detect_fixed(pattern = "arg", names(value)))) {
-#         inputArgs(object) <- rep(value$arg, length.out=length(value$files))
-#         value <- value[-pmatch("arg", names(value))]
-#       }
         value <- data.frame(value, stringsAsFactors = FALSE)
      }
-     fileTable <- .fileTableIn()
-     columns <- pmatch(names(fileTable), names(value))
-     setnames(value, old = colnames(value)[na.omit(columns)],
-                     new = colnames(fileTable)[!is.na(columns)])
-     object@inputs <- bind_rows(list(value, fileTable)) %>%
-       as.data.frame(stringsAsFactors = FALSE)
+#      fileTable <- .fileTableIn()
+#      needRenameArgs <- grepl(names(value), pattern="arg[s]?$")
+#      if (any(needRenameArgs)) {
+#        colnames(value)[needRenameArgs] <-
+#          .fileTableInCols[pmatch("arg", .fileTableInCols)]
+#      }
+#      columns <- pmatch(names(fileTable), names(value))
+#      setnames(value, old = colnames(value)[na.omit(columns)],
+#                      new = colnames(fileTable)[!is.na(columns)])
+#      columns2 <- pmatch(names(value), names(fileTable))
+#      object@inputs <- rbind(value[,na.omit(columns), drop = FALSE], fileTable[,columns2])
+#      if (any(is.na(columns))) {
+#        object@inputs[,names(fileTable[,is.na(columns)])] <- NA
+#      }
+     object@inputs <- .fillInputRows(value, start(object))
    } else {
      object@inputs <- value
    }
-
    # Deal with objects and files differently... if files (via inputs arg in simInit)...
      # Deal with file names
      # 2 things: 1. if relative, concatenate inputPath
      #           2. if absolute, don't use inputPath
-   if(NROW(value)>0) {
+   if (NROW(value)>0) {
      object@inputs[is.na(object@inputs$file), "file"] <- NA
 
      # If a filename is provided, determine if it is absolute path, if so,
@@ -1022,8 +1036,10 @@ setReplaceMethod(
        file.path(inputPath(object),
                  object@inputs$file[!isAbsolutePath(object@inputs$file) & !is.na(object@inputs$file)])
 
-     if(!all(.fileTableInCols %in% names(object@inputs))) stop(paste("input table must have columns named",
-                                                                paste(.fileTableInCols, collapse=", ")))
+     if (!all(names(object@inputs) %in% .fileTableInCols)) {
+       stop(paste("input table can only have columns named",
+                  paste(.fileTableInCols, collapse=", ")))
+     }
      if (any(is.na(object@inputs[, "loaded"]))) {
        if (!all(is.na(object@inputs[, "loadTime"]))) {
          newTime <- object@inputs[is.na(object@inputs$loaded), "loadTime"] %>%
@@ -1045,18 +1061,39 @@ setReplaceMethod(
 })
 
 ################################################################################
-#' @details \code{outputs} accepts a data.frame, with 5 columns.
-#' Currently, only \code{objectName} is required. #' Columns are:
-#' \code{objectName} (character, required),
-#' \code{file} (character),
-#' \code{fun} (character),
-#' \code{package} (character),
-#' and \code{saveTime} (numeric).
-#' Defaults:
-#' \code{file} is derived from \code{objectName}, but appending the model timeunit and
-#' \code{saveTime} to the file name (separated by underscore, "_"); \code{fun} is
-#' \code{saveRDS}; \code{package} is \code{base}; \code{interval} is NA (i.e., just once);
-#' \code{saveTime} is \code{end(sim)} time, i.e,. once at the end.
+#' @section outputs:
+#'
+#' \code{outputs} accepts a data.frame similar to the \code{inputs} data.frame, but
+#' with up to 6 columns.
+#'
+#' \tabular{ll}{
+#' \code{objectName} \tab required, character string indicating the name of the object
+#' in the \code{simList} that will be saved to disk (without the \code{sim$} prefix).\cr
+#'
+#' \code{file} \tab optional, a character string indicating the file path to save to.
+#' The default is to concatenate \code{objectName} with the model timeunit and
+#' \code{saveTime}, separated by underscore, "_". So a default filename would be
+#' "Fires_year1.rds"\cr
+#'
+#' \code{fun} \tab optional, a character string indicating the function to use to
+#' save that file. The default is \code{\link{saveRDS}} \cr
+#'
+#' \code{package} \tab optional character string indicating the package in
+#' which to find the \code{fun});\cr
+#'
+#' \code{saveTime} \tab optional numeric, indicating when in simulation time the file
+#' should be saved. The default is the lowest priority at \code{end(sim)},
+#' i.e., at the very end. \cr
+#'
+#' \code{arguments} \tab is a list of lists of named arguments, one list for each
+#' \code{fun}. For example, if \code{fun="write.csv"},
+#' \code{arguments = list(row.names = TRUE)}
+#' will pass the argument "row.names = TRUE" to write.csv  If there is only one list,
+#' then it is assumed to apply to all files and will be recycled as per normal R
+#' rules of recycling for each \code{fun}.\cr
+#'
+#' }
+#'
 #' See the modules vignette for more details (\code{browseVignettes("SpaDES")}).
 #'
 #' @note The automatic file type handling only adds the correct extension from a given
@@ -1076,6 +1113,7 @@ setReplaceMethod(
 #' @name outputs
 #' @rdname simList-accessors-inout
 #' @examples
+#' #######################
 #' # outputs
 #' startFiles <- dir(tempdir(), full.names=TRUE)
 #' tmpFile <- file.path(tempdir(), "temp.rds")
@@ -1156,15 +1194,16 @@ setMethod("outputs",
           definition = function(object) {
             simUnit <- timeunit(object)
             saveTimeUnit <- attr(object@outputs$saveTime, "unit")
-            if(is.null(saveTimeUnit)) saveTimeUnit <- simUnit
+            if (is.null(saveTimeUnit)) saveTimeUnit <- simUnit
 
-            out <- if(is.na(pmatch(saveTimeUnit, simUnit)) & (length(object@outputs$saveTime)>0)) {
+            out <- if (is.na(pmatch(saveTimeUnit, simUnit)) &
+                       length(object@outputs$saveTime) > 0) {
               #note the above line captures empty saveTime,
               # whereas is.na does not
-              if(any(!is.na(object@outputs$saveTime))) {
+              if (any(!is.na(object@outputs$saveTime))) {
                 if (!is.null(object@outputs$saveTime)) {
                   obj <- data.table::copy(object@outputs) # don't change original object
-                  obj[,saveTime:=convertTimeunit(saveTime, unit, envir(object))]
+                  obj[,saveTime := convertTimeunit(saveTime, unit, envir(object))]
                   obj[]
                   obj
                 }
@@ -1174,9 +1213,7 @@ setMethod("outputs",
             } else {
               object@outputs
             }
-
             return(out)
-
 })
 
 #' @export
@@ -1192,86 +1229,80 @@ setGeneric("outputs<-",
 #' @export
 setReplaceMethod(
   "outputs",
-   signature = ".simList",
-   function(object, value) {
-
-   if (length(value)>0) {
-     if (!is.data.frame(value)) {
-       if (!is.list(value)) {
-         stop("outputs must be a list or data.frame")
+  signature = ".simList",
+  function(object, value) {
+    if (length(value)) {
+       if (!is.data.frame(value)) {
+         if (!is.list(value)) {
+           stop("outputs must be a list or data.frame")
+         }
+         value <- data.frame(value, stringsAsFactors = FALSE)
        }
-       value <- data.frame(value, stringsAsFactors = FALSE)
+
+       object@outputs <- .fillOutputRows(value, end(object))
+
+       # coerce any factors to the correct class
+       for (col in which(sapply(object@outputs, is.factor))) {
+         object@outputs[,col] <- as(object@outputs[[col]], class(.fileTableOut()[[col]]))
+       }
+
+       # if saveTime not provided, give it end(object)
+       object@outputs[is.na(object@outputs$saveTime), "saveTime"] <-
+         end(object, timeunit(object))
+       attributes(object@outputs$saveTime)$unit <- timeunit(object)
+
+       # Deal with file names
+       # 3 things: 1. if relative, concatenate outputPath
+       #           2. if absolute, don't use outputPath
+       #           3. concatenate time to file name in all cases
+       # If no filename provided, use the object name
+       object@outputs[is.na(object@outputs$file), "file"] <-
+         paste0(object@outputs$objectName[is.na(object@outputs$file)])
+       # If a filename is provided, determine if it is absolute path, if so,
+       # use that, if not, then append it to outputPath(object)
+       object@outputs[!isAbsolutePath(object@outputs$file), "file"] <-
+         file.path(outputPath(object),
+                   object@outputs$file[!isAbsolutePath(object@outputs$file)])
+
+       # If there is no function provided, then use saveRDS, from package base
+       object@outputs[is.na(object@outputs$fun),"fun"] <- "saveRDS"
+       object@outputs[is.na(object@outputs$package),"package"] <- "base"
+
+       # file extension stuff
+       fileExts <- .saveFileExtensions()
+       fe <- suppressMessages(inner_join(object@outputs, fileExts)$exts)
+       wh <- !stri_detect_fixed(str = object@outputs$file, pattern = ".") &
+         (nchar(fe) > 0)
+       object@outputs[wh, "file"] <- paste0(object@outputs[wh, "file"], ".", fe[wh])
+
+       # If the file name already has a time unit on it,
+       # i.e., passed explicitly by user,
+       # then don't postpend again
+       txtTimeA <- paste0(attr(object@outputs[, "saveTime"], "unit"))
+       txtTimeB <- paddedFloatToChar(
+         object@outputs[,"saveTime"],
+         ceiling(log10(end(object, timeunit(object)) + 1))
+       )
+       # Add time unit and saveTime to filename, without stripping extension
+       wh <- !stri_detect_fixed(str = object@outputs$file,pattern = txtTimeA)
+       object@outputs[wh, "file"] <- paste0(
+         file_path_sans_ext(object@outputs[wh, "file"]),
+         "_", txtTimeA, txtTimeB[wh],
+         ifelse(nchar(file_ext(object@outputs[wh, "file"])) > 0, ".", ""),
+         ifelse(nchar(file_ext(object@outputs[wh, "file"])) > 0,
+                file_ext(object@outputs[wh, "file"]),
+                "")
+       )
+     } else {
+       object@outputs <- value
      }
 
-     # create a dummy data.frame with correct columns and
-     fileTable <- .fileTableOut()
-     columns <- pmatch(names(fileTable), names(value))
-     setnames(value, old = colnames(value)[na.omit(columns)],
-              new = colnames(fileTable)[!is.na(columns)])
-     # Merge
-     object@outputs <- as.data.frame(bind_rows(list(value, fileTable)))
-     #object@outputs$file <- file.path(outputPath(object),object@outputs$file)
-
-     # coerce any factors to the correct class
-     for (col in which(sapply(object@outputs, is.factor))) {
-       object@outputs[,col] <- as(object@outputs[[col]], class(fileTable[[col]]))
+     if (!all(.fileTableOutCols %in% names(object@outputs))) {
+       stop(paste("output table must have columns named",
+                  paste(.fileTableOutCols, collapse = ", ")))
      }
 
-     # if saveTime not provided, give it end(object)
-     object@outputs[is.na(object@outputs$saveTime), "saveTime"] <-
-       end(object, timeunit(object))
-     attributes(object@outputs$saveTime)$unit <- timeunit(object)
-
-     # Deal with file names
-     # 3 things: 1. if relative, concatenate outputPath
-     #           2. if absolute, don't use outputPath
-     #           3. concatenate time to file name in all cases
-     # If no filename provided, use the object name
-     object@outputs[is.na(object@outputs$file),"file"] <-
-       paste0(object@outputs$objectName[is.na(object@outputs$file)])
-     # If a filename is provided, determine if it is absolute path, if so,
-     # use that, if not, then append it to outputPath(object)
-     object@outputs[!isAbsolutePath(object@outputs$file), "file"] <-
-       file.path(outputPath(object),
-                 object@outputs$file[!isAbsolutePath(object@outputs$file)])
-
-     # If there is no function provided, then use saveRDS, from package base
-     object@outputs[is.na(object@outputs$fun),"fun"] <- "saveRDS"
-     object@outputs[is.na(object@outputs$package),"package"] <- "base"
-
-     # file extension stuff
-     fileExts <- .saveFileExtensions()
-     fe <- suppressMessages(inner_join(object@outputs, fileExts)$exts)
-     wh <- !stri_detect_fixed(str = object@outputs$file, pattern = ".") &
-       (nchar(fe) > 0)
-     object@outputs[wh, "file"] <- paste0(object@outputs[wh, "file"], ".", fe[wh])
-
-     # If the file name already has a time unit on it,
-     # i.e., passed explicitly by user,
-     # then don't postpend again
-     txtTimeA <- paste0(attr(object@outputs[, "saveTime"], "unit"))
-     txtTimeB <- paddedFloatToChar(
-       object@outputs[,"saveTime"],
-       ceiling(log10(end(object, timeunit(object))+1))
-     )
-     # Add time unit and saveTime to filename, without stripping extension
-     wh <- !stri_detect_fixed(str = object@outputs$file,pattern = txtTimeA)
-     object@outputs[wh, "file"] <- paste0(
-       file_path_sans_ext(object@outputs[wh, "file"]),
-       "_", txtTimeA, txtTimeB[wh],
-       ifelse(nchar(file_ext(object@outputs[wh, "file"]))>0,".",""),
-       ifelse(nchar(file_ext(object@outputs[wh, "file"]))>0,
-              file_ext(object@outputs[wh, "file"]),
-              "")
-     )
-   } else {
-     object@outputs <- value
-   }
-
-   if(!all(.fileTableOutCols %in% names(object@outputs))) stop(paste("output table must have columns named",
-                                                                     paste(.fileTableOutCols, collapse=", ")))
-
-   return(object)
+    return(object)
 })
 
 ################################################################################
@@ -1357,10 +1388,11 @@ setReplaceMethod(
   "outputArgs",
   signature = ".simList",
   function(object, value) {
+    argName <- .fileTableOutCols[pmatch("arg", .fileTableOutCols)]
    if (is.list(value) & !is.data.frame(value)) {
-     object@outputs$arg = value
+     object@outputs[[argName]] = value
    } else if (is.null(value)) {
-     object@outputs$arg = rep(list(NULL), NROW(outputs(object)))
+     object@outputs[[argName]] = rep(list(NULL), NROW(outputs(object)))
    } else {
      stop("value passed to outputArgs() must be a list of named elements")
    }
@@ -1447,8 +1479,8 @@ setReplaceMethod(
     if (length(na.omit(wh)) < length(value)) {
       wh1 <- !(wh[1:length(value)] %in% (1:N)[1:length(value)])
       wh2 <- !((1:N)[1:length(value)] %in% wh[1:length(value)])
-      if (length(wh1)<N) wh1 <- c(wh1, rep(FALSE, N-length(wh1)))
-      if (length(wh2)<N) wh2 <- c(wh2, rep(FALSE, N-length(wh2)))
+      if (length(wh1) < N) wh1 <- c(wh1, rep(FALSE, N - length(wh1)))
+      if (length(wh2) < N) wh2 <- c(wh2, rep(FALSE, N - length(wh2)))
       wh[wh1] <- (1:N)[wh2]
     }
 
@@ -1573,10 +1605,12 @@ setReplaceMethod("outputPath",
                  function(object, value) {
                    object@paths$outputPath <- unname(unlist(value))
                    checkPath(object@paths$outputPath, create=TRUE)
-                   if("saved" %in% colnames(outputs(object))) {
-                     notYetSaved <- !outputs(object)$saved | is.na(outputs(object)$saved)
-                     outputs(object)$file[notYetSaved] <-
-                       file.path(object@paths$outputPath, basename(outputs(object)$file[notYetSaved]))
+                   if (NROW(outputs(object))>0) {
+                     if ("saved" %in% colnames(outputs(object))) {
+                       notYetSaved <- !outputs(object)$saved | is.na(outputs(object)$saved)
+                       outputs(object)$file[notYetSaved] <-
+                         file.path(object@paths$outputPath, basename(outputs(object)$file[notYetSaved]))
+                     }
                    }
                    validObject(object)
                    return(object)
@@ -1670,6 +1704,7 @@ setReplaceMethod(
 #' @export
 #' @include simList-class.R
 #' @include times.R
+#' @importFrom chron times
 #' @docType methods
 #' @aliases simList-accessors-times
 #' @rdname simList-accessors-times
@@ -1768,7 +1803,7 @@ setMethod(
   signature = c(".simList", "character"),
   definition = function(x, unit) {
     if (!is.na(unit)) {
-      if(is.na(pmatch("second", unit))) {
+      if (is.na(pmatch("second", unit))) {
         # i.e., if not in same units as simulation
         t <- convertTimeunit(x@simtimes$current, unit, envir(x))
         return(t)
@@ -1797,8 +1832,8 @@ setReplaceMethod(
      }
      x@simtimes$current <- convertTimeunit(value, "second", envir(x))
 
-     if(!is.numeric(x@simtimes$current)) stop("time must be a numeric")
-     if(!any(pmatch(.spadesTimes,attr(x@simtimes$current, "unit")))) stop("time must be one of",
+     if (!is.numeric(x@simtimes$current)) stop("time must be a numeric")
+     if (!any(pmatch(.spadesTimes,attr(x@simtimes$current, "unit")))) stop("time must be one of",
                                                                    paste(.spadesTimes, collapse=", "))
      return(x)
 })
@@ -1838,7 +1873,7 @@ setMethod(
   definition = function(x, unit) {
 
     if (!is.na(unit)) {
-      if(is.na(pmatch("second", unit))) {
+      if (is.na(pmatch("second", unit))) {
 
         #if (!str_detect("^seconds?$", pattern = unit)) {
         # i.e., if not in same units as simulation
@@ -1906,7 +1941,7 @@ setMethod(
   signature = c(".simList","character"),
   definition = function(x, unit) {
     if (!is.na(unit)) {
-      if(is.na(pmatch("second", unit))) {
+      if (is.na(pmatch("second", unit))) {
         # i.e., if not in same units as simulation
         t <- convertTimeunit(x@simtimes$start, unit, envir(x))
         return(t)
@@ -2069,8 +2104,12 @@ setMethod(
   "timeunits",
   signature = ".simList",
   definition = function(x) {
-    isNonParent <- !sapply(depends(x)@dependencies, function(x) {
-      length(x@childModules) > 0
+    isNonParent <- !sapply(depends(x)@dependencies, function(y) {
+      if (!is.null(y)) {
+        length(y@childModules) > 0
+      } else {
+        FALSE
+      }
     })
     if (all(sapply(depends(x)@dependencies[isNonParent], is.null))) {
       timestepUnits <- NULL
@@ -2143,10 +2182,10 @@ setMethod(
   signature = c(".simList", "character"),
   definition = function(object, unit) {
 
-    out <- if(is.na(pmatch("second", unit)) & (length(object@events$eventTime)>0)) {
+    out <- if (is.na(pmatch("second", unit)) & (length(object@events$eventTime)>0)) {
       #note the above line captures empty eventTime,
       # whereas is.na does not
-      if(any(!is.na(object@events$eventTime))) {
+      if (any(!is.na(object@events$eventTime))) {
         if (!is.null(object@events$eventTime)) {
           obj <- data.table::copy(object@events) # don't change original object
           obj[, eventTime := convertTimeunit(eventTime, unit, envir(object))]
@@ -2704,3 +2743,126 @@ setMethod(
     return(df)
 })
 
+#' An internal function for coercing a data.frame to inputs()
+#'
+#' @param inputDF A data.frame with partial columns to pass to inputs( ) <-
+#' @param startTime Numeric time. The start(sim).
+#'
+#' @rdname fillInputRows
+.fillInputRows <- function(inputDF, startTime) {
+
+  fileTable <- .fileTableInCols
+  needRenameArgs <- grepl(names(inputDF), pattern="arg[s]?$")
+  if (any(needRenameArgs)) {
+    colnames(inputDF)[needRenameArgs] <-
+      .fileTableInCols[pmatch("arg", .fileTableInCols)]
+  }
+  columns <- pmatch(.fileTableInCols, names(inputDF))
+  setnames(inputDF, old = colnames(inputDF)[na.omit(columns)],
+           new = .fileTableInCols[!is.na(columns)])
+  columns2 <- pmatch(names(inputDF), .fileTableInCols)
+  if (any(is.na(columns))) {
+    inputDF[,.fileTableInCols[is.na(columns)]] <- NA
+  }
+
+  if (any(is.na(inputDF[, "loadTime"]))) {
+    inputDF[is.na(inputDF$loadTime),"loadTime"] <- startTime
+  }
+
+  if (any(is.na(inputDF[, "objectName"]))) {
+    inputDF[is.na(inputDF$objectName),"objectName"] <- fileName(inputDF[is.na(inputDF$objectName),"file"])
+  }
+
+  # correct those for which a specific function is supplied in filelistDT$fun
+  usesSemiColon <- grep(inputDF[, "fun"], pattern = "::")
+
+  if (length(usesSemiColon)>0) {
+    loadFun <- inputDF$fun[usesSemiColon]
+    splitPackFun <- strsplit(split = "::", loadFun)
+    inputDF$package[usesSemiColon] <- sapply(splitPackFun, function(x) x[1])
+    inputDF$fun[usesSemiColon] <- sapply(splitPackFun, function(x) x[2])
+  }
+
+  objectsOnly <- is.na(inputDF[, "file"])
+  if (!all(objectsOnly)) {
+    inputDF2 <- inputDF[!objectsOnly,]
+    if (any(is.na(inputDF2[, "fun"]))) {
+      .fileExts <- .fileExtensions()
+      fl <- inputDF2$file
+      exts <- na.omit(match(fileExt(fl), .fileExts[, "exts"]) )
+      inputDF2$fun[is.na(inputDF2$fun)] <- .fileExts[exts, "fun"]
+    }
+
+    if (any(is.na(inputDF2[, "package"]))) {
+      .fileExts <- .fileExtensions()
+      fl <- inputDF2$file
+      exts <- match(fileExt(fl), .fileExts[, "exts"])
+      inputDF2$package[is.na(inputDF2$package)]  <- .fileExts[exts, "package"]
+    }
+    inputDF[!objectsOnly,] <- inputDF2
+  }
+  inputDF
+}
+
+#' An internal function for coercing a data.frame to inputs()
+#'
+#' @param outputDF A data.frame with partial columns to pass to inputs( ) <-
+#' @param endTime Numeric time. The end(sim).
+#'
+#' @rdname fillOutputRows
+.fillOutputRows <- function(outputDF, endTime) {
+  needRenameArgs <- grepl(names(outputDF), pattern="arg[s]?$")
+  if (any(needRenameArgs)) {
+    colnames(outputDF)[needRenameArgs] <-
+      .fileTableOutCols[pmatch("arg", .fileTableOutCols)]
+  }
+  columns <- pmatch(.fileTableOutCols, names(outputDF))
+  setnames(outputDF, old = colnames(outputDF)[na.omit(columns)],
+           new = .fileTableOutCols[!is.na(columns)])
+  columns2 <- pmatch(names(outputDF), .fileTableOutCols)
+  #object@outputs <- rbind(outputDF[,na.omit(columns), drop = FALSE], .fileTableOut()[,columns2])
+
+  if (any(is.na(columns))) {
+    outputDF[,.fileTableOutCols[is.na(columns)]] <- NA
+  }
+  if (any(is.na(outputDF[, "saveTime"]))) {
+    outputDF[is.na(outputDF$saveTime),"saveTime"] <- endTime
+  }
+
+  # correct those for which a specific function is supplied in filelistDT$fun
+  usesSemiColon <- grep(outputDF[, "fun"], pattern = "::")
+
+  if (length(usesSemiColon)>0) {
+    loadFun <- outputDF$fun[usesSemiColon]
+    splitPackFun <- strsplit(split = "::", loadFun)
+    outputDF$package[usesSemiColon] <- sapply(splitPackFun, function(x) x[1])
+    outputDF$fun[usesSemiColon] <- sapply(splitPackFun, function(x) x[2])
+  }
+
+  if (any(is.na(outputDF[, "fun"]))) {
+    .fileExts <- .saveFileExtensions()
+    fl <- outputDF$file
+    exts <- fileExt(fl)
+    if (any(is.na(fl)) | any(nchar(exts)==0)) {
+      outputDF$fun[is.na(fl) | nchar(exts)==0] <- .fileExts$fun[1]
+    }
+    if (any(is.na(outputDF[, "fun"]))) {
+      exts <- na.omit(match(exts, .fileExts[, "exts"]) )
+      outputDF$fun[is.na(outputDF$fun)] <- .fileExts[exts, "fun"]
+    }
+  }
+
+  if (any(is.na(outputDF[, "package"]))) {
+    .fileExts <- .saveFileExtensions()
+    fl <- outputDF$file
+    exts <- fileExt(fl)
+    if (any(is.na(fl)) | any(nchar(exts)==0)) {
+      outputDF$package[is.na(fl) | nchar(exts)==0] <- .fileExts$package[1]
+    }
+    if (any(is.na(outputDF[, "package"]))) {
+      exts <- na.omit(match(fileExt(fl), .fileExts[, "exts"]) )
+      outputDF$package[is.na(outputDF$package)] <- .fileExts[exts, "package"]
+    }
+  }
+  outputDF
+}
