@@ -246,7 +246,7 @@ mySim <- simInit(times = list(start = 0.0, end = 10),
                  modules = list("randomLandscapes"),
                  paths = list(modulePath = system.file("sampleModules", package = "SpaDES"),
                               outputPath = outputDir),
-                 outputs = data.table(objectName = "landscape")
+                 outputs = data.frame(objectName = "landscape")
 )
 
 # retrieve the load and save params from the simulation object
@@ -263,11 +263,11 @@ clearPlot()
 mySim2 <- spades(mySim)
 
 # More sophisticated, passing arguments to outputs()
-outputs(mySim) <- data.table(
+outputs(mySim) <- data.frame(
   objectName = "landscape", fun = "writeRaster", package = "raster",
-  saveTime = c(3,6), args = lapply(c(3,6), function(x) {
+  saveTime = c(3,6), arguments = I(lapply(c(3,6), function(x) {
     list(dataType = "FLT4S", format = "raster", overwrite = TRUE)
-  }))
+  })))
 mySim2 <- spades(mySim)
 dev.off()
 unlink(ftmp)
